@@ -32,12 +32,12 @@
  */
 
 #define SND_LIB_MAJOR		0
-#define SND_LIB_MINOR		3
-#define SND_LIB_SUBMINOR	1
+#define SND_LIB_MINOR		4
+#define SND_LIB_SUBMINOR	0
 #define SND_LIB_VERSION		((SND_LIB_MAJOR<<16)|\
 				 (SND_LIB_MINOR<<8)|\
 				  SND_LIB_SUBMINOR)
-#define SND_LIB_VERSION_STR	"0.3.1"
+#define SND_LIB_VERSION_STR	"0.4.0"
 
 /* OBSOLETE DEFINES WHICH WON'T BE IN 0.3.0 FINAL!!! */
 #define SOUNDLIB_VERSION_MAJOR		SND_LIB_MAJOR
@@ -49,7 +49,7 @@
  */
 
 #define SND_ERROR_BEGIN				500000
-#define SND_ERROR_UNCOMPATIBLE_VERSION		(SND_ERROR_BEGIN+0)
+#define SND_ERROR_INCOMPATIBLE_VERSION		(SND_ERROR_BEGIN+0)
 
 #ifdef __cplusplus
 extern "C" {
@@ -101,15 +101,16 @@ int snd_ctl_hw_info(snd_ctl_t *handle, struct snd_ctl_hw_info *info);
 int snd_ctl_switch_list(snd_ctl_t *handle, snd_switch_list_t * list);
 int snd_ctl_switch_read(snd_ctl_t *handle, snd_switch_t * sw);
 int snd_ctl_switch_write(snd_ctl_t *handle, snd_switch_t * sw);
+int snd_ctl_hwdep_info(snd_ctl_t *handle, int dev, snd_hwdep_info_t * info);
 int snd_ctl_pcm_info(snd_ctl_t *handle, int dev, snd_pcm_info_t * info);
 int snd_ctl_pcm_playback_info(snd_ctl_t *handle, int dev, snd_pcm_playback_info_t * info);
-int snd_ctl_pcm_record_info(snd_ctl_t *handle, int dev, snd_pcm_record_info_t * info);
+int snd_ctl_pcm_capture_info(snd_ctl_t *handle, int dev, snd_pcm_capture_info_t * info);
 int snd_ctl_pcm_playback_switch_list(snd_ctl_t *handle, int dev, snd_switch_list_t * list);
 int snd_ctl_pcm_playback_switch_read(snd_ctl_t *handle, int dev, snd_switch_t * sw);
 int snd_ctl_pcm_playback_switch_write(snd_ctl_t *handle, int dev, snd_switch_t * sw);
-int snd_ctl_pcm_record_switch_list(snd_ctl_t *handle, int dev, snd_switch_list_t * list);
-int snd_ctl_pcm_record_switch_read(snd_ctl_t *handle, int dev, snd_switch_t * sw);
-int snd_ctl_pcm_record_switch_write(snd_ctl_t *handle, int dev, snd_switch_t * sw);
+int snd_ctl_pcm_capture_switch_list(snd_ctl_t *handle, int dev, snd_switch_list_t * list);
+int snd_ctl_pcm_capture_switch_read(snd_ctl_t *handle, int dev, snd_switch_t * sw);
+int snd_ctl_pcm_capture_switch_write(snd_ctl_t *handle, int dev, snd_switch_t * sw);
 int snd_ctl_mixer_info(snd_ctl_t *handle, int dev, snd_mixer_info_t * info);
 int snd_ctl_mixer_switch_list(snd_ctl_t *handle, int dev, snd_switch_list_t *list);
 int snd_ctl_mixer_switch_read(snd_ctl_t *handle, int dev, snd_switch_t * sw);
@@ -157,15 +158,19 @@ int snd_mixer_info(snd_mixer_t *handle, snd_mixer_info_t * info);
 int snd_mixer_elements(snd_mixer_t *handle, snd_mixer_elements_t * elements);
 int snd_mixer_routes(snd_mixer_t *handle, snd_mixer_routes_t * routes);
 int snd_mixer_groups(snd_mixer_t *handle, snd_mixer_groups_t * groups);
-int snd_mixer_group(snd_mixer_t *handle, snd_mixer_group_t * group);
+int snd_mixer_group_read(snd_mixer_t *handle, snd_mixer_group_t * group);
+int snd_mixer_group_write(snd_mixer_t *handle, snd_mixer_group_t * group);
 int snd_mixer_element_info(snd_mixer_t *handle, snd_mixer_element_info_t * info);
 int snd_mixer_element_read(snd_mixer_t *handle, snd_mixer_element_t * element);
 int snd_mixer_element_write(snd_mixer_t *handle, snd_mixer_element_t * element);
+int snd_mixer_read_filter(snd_mixer_t *handle, snd_mixer_filter_t * filter);
 int snd_mixer_read(snd_mixer_t *handle, snd_mixer_callbacks_t * callbacks);
 
 void snd_mixer_set_bit(unsigned int *bitmap, int bit, int val);
 int snd_mixer_get_bit(unsigned int *bitmap, int bit);
 
+const char *snd_mixer_channel_name(int channel);
+
 int snd_mixer_element_has_info(snd_mixer_eid_t *eid);
 int snd_mixer_element_info_build(snd_mixer_t *handle, snd_mixer_element_info_t * info);
 int snd_mixer_element_info_free(snd_mixer_element_info_t * info);
@@ -185,7 +190,7 @@ int snd_mixer_element_free(snd_mixer_element_t * element);
  ****************************************************************************/
 
 #define SND_PCM_OPEN_PLAYBACK	(O_WRONLY)
-#define SND_PCM_OPEN_RECORD	(O_RDONLY)
+#define SND_PCM_OPEN_CAPTURE	(O_RDONLY)
 #define SND_PCM_OPEN_DUPLEX	(O_RDWR)
 
 #ifdef __cplusplus
@@ -201,19 +206,19 @@ int snd_pcm_file_descriptor(snd_pcm_t *handle);
 int snd_pcm_block_mode(snd_pcm_t *handle, int enable);
 int snd_pcm_info(snd_pcm_t *handle, snd_pcm_info_t * info);
 int snd_pcm_playback_info(snd_pcm_t *handle, snd_pcm_playback_info_t * info);
-int snd_pcm_record_info(snd_pcm_t *handle, snd_pcm_record_info_t * info);
+int snd_pcm_capture_info(snd_pcm_t *handle, snd_pcm_capture_info_t * info);
 int snd_pcm_playback_format(snd_pcm_t *handle, snd_pcm_format_t * format);
-int snd_pcm_record_format(snd_pcm_t *handle, snd_pcm_format_t * format);
+int snd_pcm_capture_format(snd_pcm_t *handle, snd_pcm_format_t * format);
 int snd_pcm_playback_params(snd_pcm_t *handle, snd_pcm_playback_params_t * params);
-int snd_pcm_record_params(snd_pcm_t *handle, snd_pcm_record_params_t * params);
+int snd_pcm_capture_params(snd_pcm_t *handle, snd_pcm_capture_params_t * params);
 int snd_pcm_playback_status(snd_pcm_t *handle, snd_pcm_playback_status_t * status);
-int snd_pcm_record_status(snd_pcm_t *handle, snd_pcm_record_status_t * status);
+int snd_pcm_capture_status(snd_pcm_t *handle, snd_pcm_capture_status_t * status);
 int snd_pcm_drain_playback(snd_pcm_t *handle);
 int snd_pcm_flush_playback(snd_pcm_t *handle);
-int snd_pcm_flush_record(snd_pcm_t *handle);
+int snd_pcm_flush_capture(snd_pcm_t *handle);
 int snd_pcm_playback_pause(snd_pcm_t *handle, int enable);
 int snd_pcm_playback_time(snd_pcm_t *handle, int enable);
-int snd_pcm_record_time(snd_pcm_t *handle, int enable);
+int snd_pcm_capture_time(snd_pcm_t *handle, int enable);
 ssize_t snd_pcm_write(snd_pcm_t *handle, const void *buffer, size_t size);
 ssize_t snd_pcm_read(snd_pcm_t *handle, void *buffer, size_t size);
 
@@ -222,7 +227,7 @@ ssize_t snd_pcm_read(snd_pcm_t *handle, void *buffer, size_t size);
 #endif
 
 #define SND_PCM_LB_OPEN_PLAYBACK	0
-#define SND_PCM_LB_OPEN_RECORD		1
+#define SND_PCM_LB_OPEN_CAPTURE		1
 
 #ifdef __cplusplus
 extern "C" {
@@ -352,6 +357,8 @@ int snd_seq_get_queue_client(snd_seq_t *handle, int q, snd_seq_queue_client_t *q
 int snd_seq_set_queue_client(snd_seq_t *handle, int q, snd_seq_queue_client_t *queue);
 int snd_seq_alloc_queue(snd_seq_t *handle);
 int snd_seq_free_queue(snd_seq_t *handle, int q);
+int snd_seq_get_client_pool(snd_seq_t *handle, snd_seq_client_pool_t * info);
+int snd_seq_set_client_pool(snd_seq_t *handle, snd_seq_client_pool_t * info);
 /* event routines */
 snd_seq_event_t *snd_seq_create_event(void);
 int snd_seq_free_event(snd_seq_event_t *ev);
@@ -386,7 +393,7 @@ int snd_seq_get_bit(int nr, void *array);
 #define snd_host_to_BE_16(val)	((((val)>>8)&0xff)|(((val)<<8)&0xff00))
 #define snd_BE_to_host_16(val)	snd_host_to_BE_16(val)
 #define snd_host_to_BE_32(val)	((((val)>>24)&0xff)|(((val)>>16)&0xff00)|\
-                                 (((val)<<16)&0xff0000)|(((val)<<24)&0xff000000)
+                                 (((val)<<16)&0xff0000)|(((val)<<24)&0xff000000))
 #define snd_BE_to_host_32(val)	snd_host_to_BE_32(val)
 
 #else                                      
@@ -396,10 +403,10 @@ int snd_seq_get_bit(int nr, void *array);
 #define snd_host_to_BE_16(val)	(val)
 #define snd_BE_to_host_16(val)	(val)
 #define snd_host_to_LE_16(val)	((((val)>>8)&0xff)|(((val)<<8)&0xff00))
-#define snd_LE_to_host_16(val)	snd_host_to_BE_16(val)
+#define snd_LE_to_host_16(val)	snd_host_to_LE_16(val)
 #define snd_host_to_LE_32(val)	((((val)>>24)&0xff)|(((val)>>16)&0xff00)|\
-                                 (((val)<<16)&0xff0000)|(((val)<<24)&0xff000000)
-#define snd_LE_to_host_32(val)	snd_host_to_BE_32(val)
+                                 (((val)<<16)&0xff0000)|(((val)<<24)&0xff000000))
+#define snd_LE_to_host_32(val)	snd_host_to_LE_32(val)
 
 #endif
 
@@ -410,20 +417,38 @@ int snd_seq_get_bit(int nr, void *array);
  *                                                                          *
  ****************************************************************************/
 
-typedef void snd_instr_iwffff_t;
+/* Simple Wave support */
+
+typedef void snd_instr_simple_t;
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+int snd_instr_simple_convert_to_stream(snd_instr_simple_t *simple, const char *name, snd_seq_instr_put_t **put, long *size);
+int snd_instr_simple_convert_from_stream(snd_seq_instr_get_t *data, long size, snd_instr_simple_t **simple);
+int snd_instr_simple_free(snd_instr_simple_t *simple);
+
+#ifdef __cplusplus
+}
+#endif
+
 /* InterWave FFFF support */
-int snd_instr_iwffff_open(void **handle, const char *name_fff, const char *name_dta);
-int snd_instr_iwffff_open_rom(void **handle, int card, int bank, int file);
-int snd_instr_iwffff_open_rom_file(void **handle, const char *name, int bank, int file);
-int snd_instr_iwffff_close(void *handle);
-int snd_instr_iwffff_load(void *handle, int bank, int prg, snd_instr_iwffff_t **iwffff);
-int snd_instr_iwffff_convert_to_stream(snd_instr_iwffff_t *iwffff, const char *name, snd_seq_instr_data_t **data, int *size);
-int snd_instr_iwffff_convert_from_stream(snd_seq_instr_data_t *data, int size, snd_instr_iwffff_t **iwffff);
+
+typedef void snd_instr_iwffff_t;
+typedef struct snd_iwffff_handle snd_iwffff_handle_t;
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+int snd_instr_iwffff_open(snd_iwffff_handle_t **handle, const char *name_fff, const char *name_dta);
+int snd_instr_iwffff_open_rom(snd_iwffff_handle_t **handle, int card, int bank, int file);
+int snd_instr_iwffff_open_rom_file(snd_iwffff_handle_t **handle, const char *name, int bank, int file);
+int snd_instr_iwffff_close(snd_iwffff_handle_t *handle);
+int snd_instr_iwffff_load(snd_iwffff_handle_t *handle, int bank, int prg, snd_instr_iwffff_t **iwffff);
+int snd_instr_iwffff_convert_to_stream(snd_instr_iwffff_t *iwffff, const char *name, snd_seq_instr_put_t **data, long *size);
+int snd_instr_iwffff_convert_from_stream(snd_seq_instr_get_t *data, long size, snd_instr_iwffff_t **iwffff);
 int snd_instr_iwffff_free(snd_instr_iwffff_t *iwffff);
 
 #ifdef __cplusplus
