@@ -6,7 +6,7 @@
  ****************************************************************************/
 
 #define SND_PCM_OPEN_PLAYBACK	(O_WRONLY)
-#define SND_PCM_OPEN_RECORD	(O_RDONLY)
+#define SND_PCM_OPEN_CAPTURE	(O_RDONLY)
 #define SND_PCM_OPEN_DUPLEX	(O_RDWR)
 
 #ifdef __cplusplus
@@ -22,19 +22,19 @@ int snd_pcm_file_descriptor(snd_pcm_t *handle);
 int snd_pcm_block_mode(snd_pcm_t *handle, int enable);
 int snd_pcm_info(snd_pcm_t *handle, snd_pcm_info_t * info);
 int snd_pcm_playback_info(snd_pcm_t *handle, snd_pcm_playback_info_t * info);
-int snd_pcm_record_info(snd_pcm_t *handle, snd_pcm_record_info_t * info);
+int snd_pcm_capture_info(snd_pcm_t *handle, snd_pcm_capture_info_t * info);
 int snd_pcm_playback_format(snd_pcm_t *handle, snd_pcm_format_t * format);
-int snd_pcm_record_format(snd_pcm_t *handle, snd_pcm_format_t * format);
+int snd_pcm_capture_format(snd_pcm_t *handle, snd_pcm_format_t * format);
 int snd_pcm_playback_params(snd_pcm_t *handle, snd_pcm_playback_params_t * params);
-int snd_pcm_record_params(snd_pcm_t *handle, snd_pcm_record_params_t * params);
+int snd_pcm_capture_params(snd_pcm_t *handle, snd_pcm_capture_params_t * params);
 int snd_pcm_playback_status(snd_pcm_t *handle, snd_pcm_playback_status_t * status);
-int snd_pcm_record_status(snd_pcm_t *handle, snd_pcm_record_status_t * status);
+int snd_pcm_capture_status(snd_pcm_t *handle, snd_pcm_capture_status_t * status);
 int snd_pcm_drain_playback(snd_pcm_t *handle);
 int snd_pcm_flush_playback(snd_pcm_t *handle);
-int snd_pcm_flush_record(snd_pcm_t *handle);
+int snd_pcm_flush_capture(snd_pcm_t *handle);
 int snd_pcm_playback_pause(snd_pcm_t *handle, int enable);
 int snd_pcm_playback_time(snd_pcm_t *handle, int enable);
-int snd_pcm_record_time(snd_pcm_t *handle, int enable);
+int snd_pcm_capture_time(snd_pcm_t *handle, int enable);
 ssize_t snd_pcm_write(snd_pcm_t *handle, const void *buffer, size_t size);
 ssize_t snd_pcm_read(snd_pcm_t *handle, void *buffer, size_t size);
 
@@ -43,7 +43,7 @@ ssize_t snd_pcm_read(snd_pcm_t *handle, void *buffer, size_t size);
 #endif
 
 #define SND_PCM_LB_OPEN_PLAYBACK	0
-#define SND_PCM_LB_OPEN_RECORD		1
+#define SND_PCM_LB_OPEN_CAPTURE		1
 
 #ifdef __cplusplus
 extern "C" {
